==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/DockPaneAction.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PaneDragAction } from "./PaneDragAction";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { PaneDragActionType_$type } from "./PaneDragActionType";
import { DockingIndicator } from "./DockingIndicator";
import { DockManagerPane } from "./DockManagerPane";
/**
 * @hidden
 */
var DockPaneAction = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DockPaneAction, _super);
    function DockPaneAction() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = new WCNativeHelper();
        _this.f = null;
        return _this;
    }
    Object.defineProperty(DockPaneAction.prototype, "e", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockPaneAction.prototype, "nativeElement", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.d.n = this.f;
        },
        enumerable: false,
        configurable: true
    });
    DockPaneAction.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(DockPaneAction.prototype, "c", {
        get: function () {
            var ret_ = this.e.m("type");
            ret_ = enumGetBox(PaneDragActionType_$type, EnumUtil.getEnumValue(PaneDragActionType_$type, this.e.f(PaneDragActionType_$type, ret_)));
            return EnumUtil.getEnumValue(PaneDragActionType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(PaneDragActionType_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.e.u("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockPaneAction.prototype, "a", {
        get: function () {
            var ret_ = this.e.l("dockingIndicator", function (a) { return new DockingIndicator(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("dockingIndicator", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockPaneAction.prototype, "b", {
        get: function () {
            var ret_ = this.e.l("targetPane", function (a) { return DockManagerPane.createFromNative(a); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("targetPane", value_);
        },
        enumerable: false,
        configurable: true
    });
    DockPaneAction.$t = markType(DockPaneAction, 'DockPaneAction', PaneDragAction.$);
    return DockPaneAction;
}(PaneDragAction));
export { DockPaneAction };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/DockPaneAction.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PaneDragAction } from "./PaneDragAction";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { PaneDragActionType_$type } from "./PaneDragActionType";
import { DockingIndicator } from "./DockingIndicator";
import { DockManagerPane } from "./DockManagerPane";
/**
 * @hidden
 */
var DockPaneAction = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DockPaneAction, _super);
    function DockPaneAction() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = new WCNativeHelper();
        _this.f = null;
        return _this;
    }
    Object.defineProperty(DockPaneAction.prototype, "e", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockPaneAction.prototype, "nativeElement", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.d.o = this.f;
        },
        enumerable: false,
        configurable: true
    });
    DockPaneAction.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(DockPaneAction.prototype, "c", {
        get: function () {
            var ret_ = this.e.n("type");
            ret_ = enumGetBox(PaneDragActionType_$type, EnumUtil.getEnumValue(PaneDragActionType_$type, this.e.f(PaneDragActionType_$type, ret_)));
            return EnumUtil.getEnumValue(PaneDragActionType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(PaneDragActionType_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.e.v("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockPaneAction.prototype, "a", {
        get: function () {
            var ret_ = this.e.m("dockingIndicator", function (a) { return new DockingIndicator(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("dockingIndicator", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockPaneAction.prototype, "b", {
        get: function () {
            var ret_ = this.e.m("targetPane", function (a) { return DockManagerPane.createFromNative(a); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("targetPane", value_);
        },
        enumerable: false,
        configurable: true
    });
    DockPaneAction.$t = markType(DockPaneAction, 'DockPaneAction', PaneDragAction.$);
    return DockPaneAction;
}(PaneDragAction));
export { DockPaneAction };
